make-visible
open | /portal/ |
clickAt | css=#plone-contentmenu-workflow dt a span.arrowDownAlternative |
waitForVisible | css=dd.actionMenuContent |
clickAt | css=dl#plone-contentmenu-workflow dd.actionMenuContent a#workflow-transition-hide |
pause | 5000 |
waitForVisible | kssPortalMessage |
assertVisible | kssPortalMessage |
assertTextNotPresent | kssPortalMessage | ""
assertElementPresent | css=#plone-contentmenu-workflow dt a span.state-private |
clickAt | css=#plone-contentmenu-workflow dt a span.arrowDownAlternative |
waitForVisible | css=dd.actionMenuContent |
clickAt | css=dl#plone-contentmenu-workflow dd.actionMenuContent a#workflow-transition-show |
pause | 5000 |
waitForVisible | kssPortalMessage |
assertVisible | kssPortalMessage |
assertTextNotPresent | kssPortalMessage | ""
assertElementPresent | css=#plone-contentmenu-workflow dt a span.state-visible |